Installation
--------------

`neutcurve` requires Python 3.8 or newer.

The easiest way to install `neutcurve` is from `PyPI <https://pypi.org/>`_ using `pip <https://pip.pypa.io>`_ with::

    pip install neutcurve

The source code for `neutcurve` is available on GitHub at https://github.com/jbloomlab/neutcurve.
